package gssim.gssimstudio.editor.gssim.experiment
{	
	import gssim.gssimstudio.db.dao.data.Experiment;
	
	/**
	 * Class used to store experiment properties
	 */
	public class ExperimentProperties
	{
		[Bindable]
		public var workload : String;
		[Bindable]
		public var topology : String;
		[Bindable]
		public var resources : String;
		[Bindable]
		public var global : String;
		[Bindable]
		public var local : String;
		[Bindable]
		public var exec : String;
		[Bindable]
		public var metaname : String;
		[Bindable]
		public var name : String;
		[Bindable]
		public var runs : Number;
		
		private var properties : Object; // map id->value
		
		// - specifies which plugin is used to manage broker interface
		public static const statsOutputFolder : String = "stats.outputfolder";
		// - specifies which plugin is used to manage broker interface
		public static const gridSchedulingPlugin : String = "gridschedulingpluginname";
		// - specifies which plugin is used to estimate task execution time
		public static const execTimeEstimationPlugin : String = "exectimeestimationpluginname";
		// - specifies which plugin is used to manage local policies
		public static const localAllocPolicyPlugin : String = "localallocpolicypluginname";
		// - specifies file which is used to define network topology
		public static const networkTopologyFile : String = "networktopologyfilename";
		// - specifies file which is used to describe workload in SWF format
		public static const workloadFile : String = "readscenario.workloadfilename";
		// - specifies file which is used to describe workload in SWF format
		public static const resourceDescriptionFile : String = "resdesc";
		// - specifies file which is used to describe workload in SWF format
		public static const numberOfSimulations  : String = "numberofsimulations";
		
		
		public function ExperimentProperties()
		{
			properties = new Object();
			
			 //set default output folder:
			properties[statsOutputFolder] = "../../output/experiment_result";
			//set default values for plugins
			properties[gridSchedulingPlugin] = null;
			properties[execTimeEstimationPlugin] = null;
			properties[localAllocPolicyPlugin] = null;
			properties[networkTopologyFile] = null;
			properties[workloadFile] = null;
			properties[resourceDescriptionFile] = null;
			properties[numberOfSimulations] = null;
		}

		/**
		 * Returns property value given by name
		 */
		public function getProperty(propertyName :String) : Object
		{
			return properties[propertyName];
		}
		
		/**
		 * @Deprecated
		 * Sets property value given by name
		 */
		public function setProperty(propertyName :String, value : Object) : void
		{
			properties[propertyName] = value;
		}
		
		/**
		 * Writes the properties name and associated values
		 */
		public function toString():String
		{
			var output : String = "";
			for (var property : String in properties)
			{
				if (property != null && properties[property] != null)
				{
					if (property != gridSchedulingPlugin && property != localAllocPolicyPlugin && property != execTimeEstimationPlugin)
						output += property + "=" + properties[property].toString().toLowerCase() + "\r\n";
					else
						output += property + "=" + properties[property].toString() + "\r\n";
				}
			}
			return output;
		} 
		
		public function clone() : ExperimentProperties
		{
			var exp : ExperimentProperties = new ExperimentProperties();
			for (var property : String in properties)
			{
				exp.setProperty(property, properties[property]);
			}
			exp.metaname = metaname;
			exp.name = name;
			exp.resources = resources;
			exp.runs = runs;
			exp.topology = topology;
			exp.workload = workload;
			exp.global = global;
			exp.local = local;
			exp.exec = exec;
			return exp;
		}
		
		public function setWorkloadFile(file : String) : void
		{
			properties[workloadFile] = "input/workloads/" + file;
			workload = file;
		}
	
		public function setTopologyFile(file : String) : void
		{
			properties[networkTopologyFile] = "input/topologies/" + file;
			topology = file;
		}
		
		public function setResourceFile(file : String) : void
		{
			properties[resourceDescriptionFile] = "input/resources/" + file;
			resources = file;
		}
		
		public function setGlobal(item : Object) : void
		{
			properties[gridSchedulingPlugin] = item.data;
			global = item.label;
		}
		
		public function setLocal(item : Object) : void
		{
			properties[localAllocPolicyPlugin] = item.data;
			local = item.label;
		}
		
		public function setExec(item : Object) : void
		{
			properties[execTimeEstimationPlugin] = item.data;
			exec = item.label;
		}
		
		public function setRuns(runs : Number) : void
		{
			properties[numberOfSimulations] = runs;
			this.runs = runs;
		}
	}
}
